@@ -1,18 +1,16 @@
 from .base import Catalog
 from .local import LocalCatalogEntry
-from ..source import register_driver
 
 
 class ZarrGroupCatalog(Catalog):
     """A catalog of the members of a Zarr group."""
 
-    version = '0.0.1'
-    container = 'catalog'
+    version = "0.0.1"
+    container = "catalog"
     partition_access = None
-    name = 'zarr_cat'
+    name = "zarr_cat"
 
-    def __init__(self, urlpath, storage_options=None, component=None, metadata=None,
-                 consolidated=False, name=None):
+    def __init__(self, urlpath, storage_options=None, component=None, metadata=None, consolidated=False, name=None):
         """
 
         Parameters
@@ -42,7 +40,6 @@ class ZarrGroupCatalog(Catalog):
         import zarr
 
         if self._grp is None:
-
             # obtain the zarr root group
             if isinstance(self._urlpath, zarr.hierarchy.Group):
                 # use already-opened group, allows support for nested groups
@@ -50,11 +47,11 @@ class ZarrGroupCatalog(Catalog):
                 root = self._urlpath
 
             else:
-
                 # obtain store
                 if isinstance(self._urlpath, str):
                     # open store from url
                     from fsspec import get_mapper
+
                     store = get_mapper(self._urlpath, **self._storage_options)
                 else:
                     # assume store passed directly
@@ -63,9 +60,9 @@ class ZarrGroupCatalog(Catalog):
                 # open root group
                 if self._consolidated:
                     # use consolidated metadata
-                    root = zarr.open_consolidated(store=store, mode='r')
+                    root = zarr.open_consolidated(store=store, mode="r")
                 else:
-                    root = zarr.open_group(store=store, mode='r')
+                    root = zarr.open_group(store=store, mode="r")
 
             # deal with component path
             if self._component is None:
@@ -80,16 +77,9 @@ class ZarrGroupCatalog(Catalog):
         entries = {}
         for k, v in self._grp.items():
             if isinstance(v, zarr.core.Array):
-                entry = LocalCatalogEntry(name=k,
-                                          description='',
-                                          driver='ndzarr',
-                                          args=dict(urlpath=v),
-                                          catalog=self)
+                entry = LocalCatalogEntry(name=k, description="", driver="ndzarr", args=dict(urlpath=v), catalog=self)
             else:
-                entry = LocalCatalogEntry(name=k,
-                                          description='',
-                                          driver='zarr_cat',
-                                          args=dict(urlpath=v))
+                entry = LocalCatalogEntry(name=k, description="", driver="zarr_cat", args=dict(urlpath=v))
             entries[k] = entry
         self._entries = entries
 
