@@ -1,21 +1,20 @@
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Copyright (c) 2012 - 2018, Anaconda, Inc. and Intake contributors
 # All rights reserved.
 #
 # The full license is in the LICENSE file, distributed with this software.
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
 from .cache import Cache
 from .config import Config
 from .describe import Describe
 from .discover import Discover
+from .drivers import Drivers
 from .example import Example
 from .exists import Exists
 from .get import Get
 from .info import Info
 from .list import List
 from .precache import Precache
-from .drivers import Drivers
 
-all  = (Cache, Config, Describe, Discover, Example, Exists, Get, Info, List,
-        Precache, Drivers)
+all = (Cache, Config, Describe, Discover, Example, Exists, Get, Info, List, Precache, Drivers)
