@@ -1,18 +1,19 @@
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Copyright (c) 2012 - 2018, Anaconda, Inc. and Intake contributors
 # All rights reserved.
 #
 # The full license is in the LICENSE file, distributed with this software.
-#-----------------------------------------------------------------------------
-'''
-'''
+# -----------------------------------------------------------------------------
+"""
+"""
 
 import logging
+
 log = logging.getLogger(__name__)
 
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Imports
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
 # Standard library imports
 
@@ -22,18 +23,18 @@ log = logging.getLogger(__name__)
 from intake import open_catalog
 from intake.cli.util import Subcommand
 
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # API
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
+
 
 class Precache(Subcommand):
-    ''' Populate caching for catalog entries that define caching.
-    '''
+    """Populate caching for catalog entries that define caching."""
 
     name = "precache"
 
     def initialize(self):
-        self.parser.add_argument('uri', metavar='URI', type=str, help='Catalog URI')
+        self.parser.add_argument("uri", metavar="URI", type=str, help="Catalog URI")
 
     def invoke(self, args):
         catalog = open_catalog(args.uri)
