@@ -1,18 +1,18 @@
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Copyright (c) 2012 - 2018, Anaconda, Inc. and Intake contributors
 # All rights reserved.
 #
 # The full license is in the LICENSE file, distributed with this software.
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
 import msgpack
-from .utils import encode_datetime, decode_datetime
 
+from .utils import decode_datetime, encode_datetime
 
 if msgpack.version >= (0, 5, 2):
-    unpack_kwargs = {'raw': False}
+    unpack_kwargs = {"raw": False}
 else:
-    unpack_kwargs = {'encoding': 'utf-8'}
+    unpack_kwargs = {"encoding": "utf-8"}
 
 unpack_kwargs["object_hook"] = decode_datetime
 
@@ -24,6 +24,7 @@ pack_kwargs = dict(
 
 try:
     import msgpack_numpy
+
     np_unpack_kwargs = dict(
         object_hook=lambda obj: decode_datetime(msgpack_numpy.decode(obj)),
     )
@@ -32,5 +33,3 @@ try:
     )
 except ImportError:
     pass
-
-
