@@ -1,21 +1,22 @@
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Copyright (c) 2012 - 2018, Anaconda, Inc. and Intake contributors
 # All rights reserved.
 #
 # The full license is in the LICENSE file, distributed with this software.
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
-from collections import OrderedDict
 import gzip
 import io
 import pickle
+from collections import OrderedDict
 
 import msgpack
 
 from ..compat import pack_kwargs
 
+
 class NoneCompressor(object):
-    name = 'none'
+    name = "none"
 
     def compress(self, data):
         return data
@@ -25,11 +26,11 @@ class NoneCompressor(object):
 
 
 class GzipCompressor(object):
-    name = 'gzip'
+    name = "gzip"
 
     def compress(self, data):
         buf = io.BytesIO()
-        with gzip.GzipFile(fileobj=buf, mode='wb', compresslevel=1) as f:
+        with gzip.GzipFile(fileobj=buf, mode="wb", compresslevel=1) as f:
             f.write(data)
         return buf.getvalue()
 
@@ -52,17 +53,17 @@ def check_pyarrow():
     return pyarrow
 
 
-
 class MsgPackSerializer(object):
     # TODO: This is ugly, should maybe transition to
     #  distributed.protocol.serialize
-    name = 'msgpack'
+    name = "msgpack"
 
     def encode(self, obj, container):
-        if container in ['ndarray', 'xarray'] and msgpack_numpy:
+        if container in ["ndarray", "xarray"] and msgpack_numpy:
             from ..compat import np_pack_kwargs
+
             return msgpack.packb(obj, **np_pack_kwargs)
-        elif container == 'dataframe':
+        elif container == "dataframe":
             # Use pyarrow for serializing DataFrames, rather than
             # msgpack: https://github.com/intake/intake/issues/460
             pa = check_pyarrow()
@@ -77,10 +78,12 @@ class MsgPackSerializer(object):
 
     def decode(self, bytestr, container):
         from ..compat import unpack_kwargs
-        if container in ['ndarray', 'xarray'] and msgpack_numpy:
+
+        if container in ["ndarray", "xarray"] and msgpack_numpy:
             from ..compat import np_unpack_kwargs
+
             return msgpack.unpackb(bytestr, **np_unpack_kwargs)
-        elif container == 'dataframe':
+        elif container == "dataframe":
             pa = check_pyarrow()
             context = pa.default_serialization_context()
             return context.deserialize(bytestr)
@@ -91,7 +94,7 @@ class MsgPackSerializer(object):
 class PickleSerializer(object):
     def __init__(self, protocol_level):
         self._protocol_level = protocol_level
-        self.name = 'pickle%d' % protocol_level
+        self.name = "pickle%d" % protocol_level
 
     def encode(self, obj, container):
         return pickle.dumps(obj, protocol=self._protocol_level)
@@ -108,21 +111,18 @@ class ComboSerializer(object):
         self.compressor_name = compressor.name
 
     def encode(self, obj, container):
-        return self._compressor.compress(
-            self._format_encoder.encode(obj, container))
+        return self._compressor.compress(self._format_encoder.encode(obj, container))
 
     def decode(self, bytestr, container):
-        return self._format_encoder.decode(
-            self._compressor.decompress(bytestr), container)
+        return self._format_encoder.decode(self._compressor.decompress(bytestr), container)
 
 
 compressors = [GzipCompressor(), NoneCompressor()]
 try:
     import snappy
 
-
     class SnappyCompressor(object):
-        name = 'snappy'
+        name = "snappy"
 
         def compress(self, data):
             return snappy.compress(data)
@@ -130,7 +130,6 @@ try:
         def decompress(self, data):
             return snappy.decompress(data)
 
-
     compressors.insert(0, SnappyCompressor())
 except ImportError:
     pass
