@@ -1,22 +1,24 @@
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Copyright (c) 2012 - 2022, Anaconda, Inc. and Intake contributors
 # All rights reserved.
 #
 # The full license is in the LICENSE file, distributed with this software.
-#-----------------------------------------------------------------------------
-from packaging.version import Version
+# -----------------------------------------------------------------------------
 import hvplot
+from packaging.version import Version
 
 try:
     import xrviz
     from xrviz.dashboard import Dashboard as XRViz
+
     assert Version(xrviz.__version__) >= Version("0.1.1")
 except ImportError:
     xrviz = False
 
 import panel as pn
-from ..base import BaseView
+
 from ...catalog.local import LocalCatalogEntry, YAMLFileCatalog
+from ..base import BaseView
 
 
 class Event:
@@ -53,41 +55,37 @@ class Plots(BaseView):
         watchers that are set on children - cleaned up when visible
         is set to false.
     """
+
     select = None
 
     def __init__(self, source=None, **kwargs):
-        self.custom = pn.widgets.Button(name='Create', width=70, align='center')
+        self.custom = pn.widgets.Button(name="Create", width=70, align="center")
         self.source = source
-        self.panel = pn.Column(name='Plot', width_policy='max', margin=0)
+        self.panel = pn.Column(name="Plot", width_policy="max", margin=0)
         self._behavior_callback = None
         self._callbacks = []
         super().__init__(**kwargs)
 
     def setup(self):
-        self.instructions = pn.pane.Markdown(
-            "**Select Plot**", align='center', width=70)
-        self.select = pn.widgets.Select(options=self.options, height=30,
-                                        align='center', min_width=200)
+        self.instructions = pn.pane.Markdown("**Select Plot**", align="center", width=70)
+        self.select = pn.widgets.Select(options=self.options, height=30, align="center", min_width=200)
         # Add spaces in front of each option to make it render correctly.
         # This is a bit of a hack to make a Select which only displays the down arrow.
-        self.edit_options = pn.widgets.Select(options=['  Edit', '  Clone', '  Rename', '  Delete'],
-                                              align='center',
-                                              width=25, margin=(5, -10))
-        self.pane = pn.pane.HoloViews(self._plot_object(self.selected),
-                                      name="Plot")
+        self.edit_options = pn.widgets.Select(options=["  Edit", "  Clone", "  Rename", "  Delete"], align="center", width=25, margin=(5, -10))
+        self.pane = pn.pane.HoloViews(self._plot_object(self.selected), name="Plot")
 
-        self.interact_label = pn.pane.Markdown('Name', align='center', width_policy='max', min_width=100)
-        self.interact_name = pn.widgets.TextInput(placeholder='Name of new plot...')
+        self.interact_label = pn.pane.Markdown("Name", align="center", width_policy="max", min_width=100)
+        self.interact_name = pn.widgets.TextInput(placeholder="Name of new plot...")
         self.interact_cancel = pn.widgets.Button(name="Cancel", width=100)
-        self.interact_save = pn.widgets.Button(name="Save", button_type='primary', width=100)
+        self.interact_save = pn.widgets.Button(name="Save", button_type="primary", width=100)
 
         self.watchers = [
-            self.select.param.watch(self.plot_selected, ['value']),
-            self.custom.param.watch(self.interact, ['clicks']),
-            self.edit_options.param.watch(self.interact, ['value']),
-            self.interact_name.param.watch(self.name_changed, ['value_input']),
-            self.interact_cancel.param.watch(self.cancel, ['clicks']),
-            self.interact_save.param.watch(self.interact_action, ['clicks']),
+            self.select.param.watch(self.plot_selected, ["value"]),
+            self.custom.param.watch(self.interact, ["clicks"]),
+            self.edit_options.param.watch(self.interact, ["value"]),
+            self.interact_name.param.watch(self.name_changed, ["value_input"]),
+            self.interact_cancel.param.watch(self.cancel, ["clicks"]),
+            self.interact_save.param.watch(self.interact_action, ["clicks"]),
         ]
         self.alert = pn.pane.Alert(alert_type="danger")
         self.out = pn.Row(self.pane, name="Plot")
@@ -128,9 +126,9 @@ class Plots(BaseView):
         BaseView.source.fset(self, source)
         if self.select:
             self.select.options = self.options
-        if source and source.container == 'dataframe':
+        if source and source.container == "dataframe":
             self.custom.disabled = False
-        elif source and xrviz and source.container in ['xarray', 'ndarray', 'numpy']:
+        elif source and xrviz and source.container in ["xarray", "ndarray", "numpy"]:
             self.custom.disabled = False
         else:
             self.custom.disabled = True
@@ -143,7 +141,7 @@ class Plots(BaseView):
     @property
     def options(self):
         """Plots options defined on the source"""
-        return (['None'] + self.source.plots) if self.source is not None else []
+        return (["None"] + self.source.plots) if self.source is not None else []
 
     @property
     def selected(self):
@@ -160,9 +158,9 @@ class Plots(BaseView):
 
     def plot_selected(self, *events):
         for event in events:
-            if event.name == 'value':
+            if event.name == "value":
                 self.pane.object = self._plot_object(event.new)
-            self.custom.name = "Create" if str(self.select.value) == 'None' else "Edit"
+            self.custom.name = "Create" if str(self.select.value) == "None" else "Edit"
             self.edit_options.visible = self.custom.name == "Edit"
 
     def name_changed(self, *events):
@@ -209,40 +207,40 @@ class Plots(BaseView):
             # This is a short-circuit to allow edit options reset
             # without causing an infinite loop
             return
-        if self.selected == 'None':
+        if self.selected == "None":
             # Create
             self._behavior_callback = self._create
-            self.interact_save.name = 'Save'
+            self.interact_save.name = "Save"
             self.interact_save.disabled = True
-            self.interact_label.object = f'Name '
+            self.interact_label.object = "Name "
             self.interact_name.value = ""
             self.interact_name.visible = True
             viz = self.draw()
             self.out[0] = viz
-        elif self.edit_options.value == '  Clone':
+        elif self.edit_options.value == "  Clone":
             self._behavior_callback = self._clone
-            self.interact_save.name = 'Clone'
+            self.interact_save.name = "Clone"
             self.interact_save.disabled = True
             self.interact_label.object = f'Clone "**{self.selected}**" as '
             self.interact_name.value = ""
             self.interact_name.visible = True
-        elif self.edit_options.value == '  Rename':
+        elif self.edit_options.value == "  Rename":
             self._behavior_callback = self._rename
-            self.interact_save.name = 'Rename'
+            self.interact_save.name = "Rename"
             self.interact_save.disabled = True
             self.interact_label.object = f'Rename "**{self.selected}**" to '
             self.interact_name.value = ""
             self.interact_name.visible = True
-        elif self.edit_options.value == '  Delete':
+        elif self.edit_options.value == "  Delete":
             self._behavior_callback = self._delete
-            self.interact_save.name = 'Delete'
+            self.interact_save.name = "Delete"
             self.interact_save.disabled = False
             self.interact_label.object = f'Really delete "**{self.selected}**" ?'
             self.interact_name.visible = False
-        elif self.edit_options.value == '  Edit':
+        elif self.edit_options.value == "  Edit":
             # Edit
             self._behavior_callback = self._edit
-            self.interact_save.name = 'Save'
+            self.interact_save.name = "Save"
             self.interact_save.disabled = False
             self.interact_label.object = f'Editing "**{self.selected}**"'
             self.interact_name.visible = False
@@ -255,20 +253,21 @@ class Plots(BaseView):
         self.row_select_plots.visible = False
         # Reset edit options selection (won't trigger
         # edit action because _behavior_callback is set)
-        self.edit_options.value = 'Edit'
+        self.edit_options.value = "Edit"
 
     def draw(self):
-        if self.selected == 'None':
-            kwargs = {'y': []}
+        if self.selected == "None":
+            kwargs = {"y": []}
         else:
-            kwargs = self.source.metadata['plots'][self.selected]
-        if self.source.container == 'dataframe':
+            kwargs = self.source.metadata["plots"][self.selected]
+        if self.source.container == "dataframe":
             df = self.source.to_dask()
             if df.npartitions == 1:
                 df = df.compute()
             self._viz = viz = hvplot.explorer(df, **kwargs)
-        elif self.source.container in ['xarray', 'ndarray', 'numpy']:
+        elif self.source.container in ["xarray", "ndarray", "numpy"]:
             import xarray
+
             try:
                 data = self.source.to_dask()
             except NotImplementedError:
@@ -291,8 +290,8 @@ class Plots(BaseView):
     def _create(self):
         plot_name = self.interact_name.value
         # Add plot metadata to both DataSource and CatalogEntry
-        self.source.metadata.setdefault('plots', {})[plot_name] = self._viz.settings()
-        self.source.entry._metadata.setdefault('plots', {})[plot_name] = self._viz.settings()
+        self.source.metadata.setdefault("plots", {})[plot_name] = self._viz.settings()
+        self.source.entry._metadata.setdefault("plots", {})[plot_name] = self._viz.settings()
         # Add new plot name to self.options
         self.select.options = self.options
         # Select new graph
@@ -301,15 +300,15 @@ class Plots(BaseView):
 
     def _edit(self):
         # Update plot metadata for both DataSource and CatalogEntry
-        self.source.metadata['plots'][self.selected] = self._viz.settings()
-        self.source.entry._metadata['plots'][self.selected] = self._viz.settings()
+        self.source.metadata["plots"][self.selected] = self._viz.settings()
+        self.source.entry._metadata["plots"][self.selected] = self._viz.settings()
         return Event(self, kind="edit", plot_name=self.selected)
 
     def _clone(self):
         plot_name = self.interact_name.value
         # Clone plot metadata for both DataSource and CatalogEntry
-        self.source.metadata['plots'][plot_name] = self.source.metadata['plots'][self.selected].copy()
-        self.source.entry._metadata['plots'][plot_name] = self.source.entry._metadata['plots'][self.selected].copy()
+        self.source.metadata["plots"][plot_name] = self.source.metadata["plots"][self.selected].copy()
+        self.source.entry._metadata["plots"][plot_name] = self.source.entry._metadata["plots"][self.selected].copy()
         # Add new plot name to self.options
         self.select.options = self.options
         # Select new graph
@@ -319,8 +318,8 @@ class Plots(BaseView):
     def _rename(self):
         plot_name = self.interact_name.value
         # Rename plot metadata for both DataSource and CatalogEntry
-        self.source.metadata['plots'][plot_name] = self.source.metadata['plots'].pop(self.selected)
-        self.source.entry._metadata['plots'][plot_name] = self.source.entry._metadata['plots'].pop(self.selected)
+        self.source.metadata["plots"][plot_name] = self.source.metadata["plots"].pop(self.selected)
+        self.source.entry._metadata["plots"][plot_name] = self.source.entry._metadata["plots"].pop(self.selected)
         # Update available options in dropdown
         self.select.options = self.options
         # Select renamed graph
@@ -329,20 +328,22 @@ class Plots(BaseView):
 
     def _delete(self):
         # Delete plot metadata from both DataSource and CatalogEntry
-        del self.source.metadata['plots'][self.selected]
-        del self.source.entry._metadata['plots'][self.selected]
+        del self.source.metadata["plots"][self.selected]
+        del self.source.entry._metadata["plots"][self.selected]
         # Update available options in dropdown
         self.select.options = self.options
-        self.selected = 'None'
+        self.selected = "None"
         return Event(self, kind="delete", plot_name=self.selected)
 
     def __getstate__(self, include_source=True):
         """Serialize the current state of the object. Set include_source
         to False when using with another panel that will include source."""
         state = super().__getstate__(include_source)
-        state.update({
-            'selected': self.selected,
-        })
+        state.update(
+            {
+                "selected": self.selected,
+            }
+        )
         return state
 
     def __setstate__(self, state):
@@ -351,5 +352,5 @@ class Plots(BaseView):
         ``from_state`` to create a new object."""
         super().__setstate__(state)
         if self.visible:
-            self.selected = state.get('selected')
+            self.selected = state.get("selected")
         return self
