@@ -1,16 +1,17 @@
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Copyright (c) 2012 - 2019, Anaconda, Inc. and Intake contributors
 # All rights reserved.
 #
 # The full license is in the LICENSE file, distributed with this software.
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 from functools import partial
+
 import panel as pn
 
-from ..base import Base, enable_widget, MAX_WIDTH
-from .select import SourceSelector
+from ..base import MAX_WIDTH, Base, enable_widget
 from .defined_plots import Plots
 from .description import Description
+from .select import SourceSelector
 
 
 class SourceGUI(Base):
@@ -41,45 +42,32 @@ class SourceGUI(Base):
         watchers that are set on children - cleaned up when visible
         is set to false.
     """
+
     def __init__(self, cats=None, sources=None, done_callback=None, **kwargs):
         self._cats = cats
         self._sources = sources
-        self.panel = pn.Column(name='Entries', width_policy='max',
-                               max_width=MAX_WIDTH)
+        self.panel = pn.Column(name="Entries", width_policy="max", max_width=MAX_WIDTH)
         self.done_callback = done_callback
 
-        self.plot_widget = pn.widgets.Toggle(
-            name='📊',
-            value=False,
-            disabled=True,
-            width=50)
-        self.pars_widget = pn.widgets.Toggle(
-            name='⚙',
-            value=False,
-            disabled=True,
-            width=50)
+        self.plot_widget = pn.widgets.Toggle(name="📊", value=False, disabled=True, width=50)
+        self.pars_widget = pn.widgets.Toggle(name="⚙", value=False, disabled=True, width=50)
         self.controls = [self.plot_widget, self.pars_widget]
-        self.control_panel = pn.Row(name='Controls', margin=0)
+        self.control_panel = pn.Row(name="Controls", margin=0)
 
         self.pars_editor = ParsEditor()
-        self.select = SourceSelector(cats=self._cats,
-                                     sources=self._sources,
-                                     done_callback=self.callback)
+        self.select = SourceSelector(cats=self._cats, sources=self._sources, done_callback=self.callback)
         self.description = Description()
         self.description.source = self.sources
 
-        self.plot = Plots(source=self.source_instance,
-                          visible=self.plot_widget.value,
-                          visible_callback=partial(
-                          setattr, self.plot_widget, 'value'))
+        self.plot = Plots(source=self.source_instance, visible=self.plot_widget.value, visible_callback=partial(setattr, self.plot_widget, "value"))
 
         super().__init__(**kwargs)
 
     def _setup_watchers(self):
         self.watchers = [
-            self.plot_widget.param.watch(self.on_click_plot_widget, 'value'),
-            self.pars_widget.param.watch(self.on_click_pars_widget, 'value'),
-            self.select.widget.link(self.description, value='source'),
+            self.plot_widget.param.watch(self.on_click_plot_widget, "value"),
+            self.pars_widget.param.watch(self.on_click_pars_widget, "value"),
+            self.select.widget.link(self.description, value="source"),
         ]
         self.plot.watch(self.on_plot_edited)
 
@@ -98,7 +86,7 @@ class SourceGUI(Base):
                 ),
                 self.plot.panel,
                 margin=0,
-                width_policy='max'
+                width_policy="max",
             )
         ]
 
@@ -128,7 +116,7 @@ class SourceGUI(Base):
     def callback(self, sources):
         """When a source is selected, enable widgets that depend on that condition
         and do done_callback"""
-        if hasattr(self, 'plot'):
+        if hasattr(self, "plot"):
             # guard since this cannot happen until plot is ready
             self.plot.visible = False
         enable = bool(sources)
@@ -143,7 +131,7 @@ class SourceGUI(Base):
             self.done_callback(sources)
 
     def on_click_plot_widget(self, event):
-        """ When the plot control is toggled, set visibility and hand down source"""
+        """When the plot control is toggled, set visibility and hand down source"""
         self.plot.source = self.source_instance
         self.plot.visible = event.new
 
@@ -175,21 +163,21 @@ class SourceGUI(Base):
     def __getstate__(self):
         """Serialize the current state of the object"""
         return {
-            'visible': self.visible,
-            'select': self.select.__getstate__(),
-            'description': self.description.__getstate__(include_source=False),
-            'plot':  self.plot.__getstate__(include_source=False),
+            "visible": self.visible,
+            "select": self.select.__getstate__(),
+            "description": self.description.__getstate__(include_source=False),
+            "plot": self.plot.__getstate__(include_source=False),
         }
 
     def __setstate__(self, state):
         """Set the current state of the object from the serialized version.
         Works inplace. See ``__getstate__`` to get serialized version and
         ``from_state`` to create a new object."""
-        self.visible = state.get('visible', True)
+        self.visible = state.get("visible", True)
         if self.visible:
-            self.select.__setstate__(state['select'])
-            self.description.__setstate__(state['description'])
-            self.plot.__setstate__(state['plot'])
+            self.select.__setstate__(state["select"])
+            self.description.__setstate__(state["description"])
+            self.plot.__setstate__(state["plot"])
         return self
 
     @classmethod
@@ -230,13 +218,13 @@ class ParsEditor(Base):
     def par_to_widget(par):
         if par.allowed:
             w = pn.widgets.Select(options=par.allowed)
-        elif par.type in ['str', 'unicode']:
+        elif par.type in ["str", "unicode"]:
             w = pn.widgets.TextInput()
-        elif par.type == 'int':
+        elif par.type == "int":
             w = pn.widgets.IntSlider(start=par.min, end=par.max, step=1)
-        elif par.type == 'float':
+        elif par.type == "float":
             w = pn.widgets.FloatSlider(start=par.min, end=par.max)
-        elif par.type == 'datetime':
+        elif par.type == "datetime":
             w = pn.widgets.DatetimeInput()
         else:
             w = pn.widgets.LiteralInput()
