@@ -1,19 +1,19 @@
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Copyright (c) 2012 - 2018, Anaconda, Inc. and Intake contributors
 # All rights reserved.
 #
 # The full license is in the LICENSE file, distributed with this software.
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
+import logging
 from collections.abc import MappingView
 
 import entrypoints
-import logging
 
 from .base import DataSource
 from .discovery import drivers
 
-logger = logging.getLogger('intake')
+logger = logging.getLogger("intake")
 
 
 class DriverRegistry(MappingView):
@@ -22,6 +22,7 @@ class DriverRegistry(MappingView):
     If the value object is a EntryPoint or str, will load it when accesses, which
     does the import.
     """
+
     def __init__(self, drivers_source=drivers):
         self.drivers = drivers_source
 
@@ -53,6 +54,7 @@ class DriverRegistry(MappingView):
 
 registry = DriverRegistry()
 register_driver = drivers.register_driver
+unregister_driver = drivers.unregister_driver
 
 # A set of fully-qualified package.module.Class mappings
 classes = {}
@@ -60,6 +62,7 @@ classes = {}
 
 def import_name(name):
     import importlib
+
     if ":" in name:
         if name.count(":") > 1:
             raise ValueError("Cannot decipher name to import: %s", name)
@@ -69,7 +72,7 @@ def import_name(name):
             bit = getattr(bit, part)
         return bit
     else:
-        mod, cls = name.rsplit('.', 1)
+        mod, cls = name.rsplit(".", 1)
         module = importlib.import_module(mod)
         return getattr(module, cls)
 
@@ -77,7 +80,7 @@ def import_name(name):
 def get_plugin_class(name):
     if name in registry:
         return registry[name]
-    if '.' not in name:
+    if "." not in name:
         logger.debug('Plugin name "%s" not known' % name)
         return None
     if name not in classes:
