@@ -1,12 +1,12 @@
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Copyright (c) 2012 - 2018, Anaconda, Inc. and Intake contributors
 # All rights reserved.
 #
 # The full license is in the LICENSE file, distributed with this software.
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
 from . import base
-from .utils import DASK_VERSION, reverse_formats, unique_string
+from .utils import reverse_formats, unique_string
 
 
 class CSVSource(base.DataSource, base.PatternMixin):
@@ -15,13 +15,13 @@ class CSVSource(base.DataSource, base.PatternMixin):
     Prototype of sources reading dataframe data
 
     """
-    name = 'csv'
-    version = '0.0.1'
-    container = 'dataframe'
+
+    name = "csv"
+    version = "0.0.1"
+    container = "dataframe"
     partition_access = True
 
-    def __init__(self, urlpath, csv_kwargs=None, metadata=None,
-                 storage_options=None, path_as_pattern=True):
+    def __init__(self, urlpath, csv_kwargs=None, metadata=None, storage_options=None, path_as_pattern=True):
         """
         Parameters
         ----------
@@ -56,51 +56,43 @@ class CSVSource(base.DataSource, base.PatternMixin):
         super(CSVSource, self).__init__(metadata=metadata)
 
     def _set_pattern_columns(self, path_column):
-        """Get a column of values for each field in pattern
-        """
+        """Get a column of values for each field in pattern"""
         from pandas.api.types import CategoricalDtype
 
         col = self._dataframe[path_column]
         paths = sorted(col.cat.categories)
 
-        column_by_field = {field:
-            col.cat.codes.map(dict(enumerate(values))).astype(
-                CategoricalDtype(set(values))
-            ) for field, values in reverse_formats(self.pattern, paths).items()
+        column_by_field = {
+            field: col.cat.codes.map(dict(enumerate(values))).astype(CategoricalDtype(set(values))) for field, values in reverse_formats(self.pattern, paths).items()
         }
         self._dataframe = self._dataframe.assign(**column_by_field)
 
     def _path_column(self):
-        """Set ``include_path_column`` in csv_kwargs and returns path column name
-        """
-        path_column = self._csv_kwargs.get('include_path_column')
+        """Set ``include_path_column`` in csv_kwargs and returns path column name"""
+        path_column = self._csv_kwargs.get("include_path_column")
 
         if path_column is None:
             # if path column name is not set by user, set to a unique string to
             # avoid conflicts
             path_column = unique_string()
-            self._csv_kwargs['include_path_column'] = path_column
+            self._csv_kwargs["include_path_column"] = path_column
         elif isinstance(path_column, bool):
-            path_column = 'path'
-            self._csv_kwargs['include_path_column'] = path_column
+            path_column = "path"
+            self._csv_kwargs["include_path_column"] = path_column
         return path_column
 
     def _open_dataset(self, urlpath):
-        """Open dataset using dask and use pattern fields to set new columns
-        """
+        """Open dataset using dask and use pattern fields to set new columns"""
         import dask.dataframe
 
         if self.pattern is None:
-            self._dataframe = dask.dataframe.read_csv(
-                urlpath, storage_options=self._storage_options,
-                **self._csv_kwargs)
+            self._dataframe = dask.dataframe.read_csv(urlpath, storage_options=self._storage_options, **self._csv_kwargs)
             return
 
-        drop_path_column = 'include_path_column' not in self._csv_kwargs
+        drop_path_column = "include_path_column" not in self._csv_kwargs
         path_column = self._path_column()
 
-        self._dataframe = dask.dataframe.read_csv(
-            urlpath, storage_options=self._storage_options, **self._csv_kwargs)
+        self._dataframe = dask.dataframe.read_csv(urlpath, storage_options=self._storage_options, **self._csv_kwargs)
 
         # add the new columns to the dataframe
         self._set_pattern_columns(path_column)
@@ -116,10 +108,7 @@ class CSVSource(base.DataSource, base.PatternMixin):
 
         dtypes = self._dataframe._meta.dtypes.to_dict()
         dtypes = {n: str(t) for (n, t) in dtypes.items()}
-        return base.Schema(dtype=dtypes,
-                           shape=(None, len(dtypes)),
-                           npartitions=self._dataframe.npartitions,
-                           extra_metadata={})
+        return base.Schema(dtype=dtypes, shape=(None, len(dtypes)), npartitions=self._dataframe.npartitions, extra_metadata={})
 
     def _get_partition(self, i):
         self._get_schema()
@@ -135,12 +124,8 @@ class CSVSource(base.DataSource, base.PatternMixin):
 
     def to_spark(self):
         from intake_spark.base import SparkHolder
-        h = SparkHolder(True, [
-            ('read', ),
-            ('format', ("csv", )),
-            ('option', ("header", "true")),
-            ('load', (self.urlpath, ))
-        ], {})
+
+        h = SparkHolder(True, [("read",), ("format", ("csv",)), ("option", ("header", "true")), ("load", (self.urlpath,))], {})
         return h.setup()
 
     def _close(self):
