@@ -1,22 +1,23 @@
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Copyright (c) 2012 - 2018, Anaconda, Inc. and Intake contributors
 # All rights reserved.
 #
 # The full license is in the LICENSE file, distributed with this software.
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
-from collections.abc import MutableMapping
-import pkgutil
-import warnings
 import importlib
 import inspect
-import time
 import logging
+import pkgutil
+import re
+import time
+import warnings
 
 import entrypoints
 
 from ..config import conf
-logger = logging.getLogger('intake')
+
+logger = logging.getLogger("intake")
 
 
 class DriverSouces:
@@ -40,7 +41,8 @@ class DriverSouces:
         self.do_scan = do_scan
         self._scanned = None
         self._entrypoints = None
-        self.registered = {}
+        self._registered = None
+        self._disabled = None
 
     @property
     def package_scan(self):
@@ -59,16 +61,12 @@ class DriverSouces:
     def from_conf(self):
         return [
             entrypoints.EntryPoint(
-                name=k,
-                module_name=v.rsplit(":", 1)[0] if ":" in v else v.rsplit(".", 1)[0],
-                object_name=v.rsplit(":", 1)[1] if ":" in v else v.rsplit(".", 1)[1]
+                name=k, module_name=v.rsplit(":", 1)[0] if ":" in v else v.rsplit(".", 1)[0], object_name=v.rsplit(":", 1)[1] if ":" in v else v.rsplit(".", 1)[1]
             )
-            for k, v in self.conf.get("drivers", {}).items() if v
+            for k, v in self.conf.get("drivers", {}).items()
+            if v
         ]
 
-    def disabled(self):
-        return [k for k, v in self.conf.get("drivers", {}).items() if v is False]
-
     def __setitem__(self, key, value):
         super(DriverSouces, self).__setitem__(key, value)
         self.save()
@@ -85,21 +83,31 @@ class DriverSouces:
             self._scanned = _package_scan()
         return self._scanned
 
-    def enabled_plugins(self):
+    def disabled(self):
+        if self._disabled is None:
+            self._disabled = {k for k, v in self.conf.get("drivers", {}).items() if v is False}
+
+        return self._disabled
+
+    def registered(self):
         # priority order (decreasing): runtime, config, entrypoints, package scan
-        out = {}
-        if self.package_scan:
-            out.update(self.scanned)
+        if self._registered is None:
+            out = {}
+            if self.package_scan:
+                out.update(self.scanned)
 
-        for ep in self.from_entrypoints() + self.from_conf():
-            out[ep.name] = ep
+            for ep in self.from_entrypoints() + self.from_conf():
+                out[ep.name] = ep
 
-        out.update(self.registered)
-        out = {k: v for k, v in out.items() if k not in self.disabled()}
-        return out
+            self._registered = out
+
+        return self._registered
+
+    def enabled_plugins(self):
+        return {k: v for k, v in self.registered().items() if k not in self.disabled()}
 
     def register_driver(self, name, value, clobber=False, do_enable=False):
-        """Add runtime driver definition
+        """Add runtime driver definition to list of registered drivers (drivers in global scope with corresponding ``intake.open_*`` function)
 
         Parameters
         ----------
@@ -112,19 +120,21 @@ class DriverSouces:
         do_enable: bool
             If True, unset the disabled flag for this driver
         """
-        if not clobber and name in self.enabled_plugins():
+        name = _normalize(name)
+        if name in self.registered() and not clobber:
             raise ValueError(f"Driver {name} already enabled")
         if name in self.disabled():
             if do_enable:
-                self.enable(name)
+                self.enable(name, value)
             else:
                 logger.warning(f"Adding driver {name}, but it is disabled")
 
-        self.registered[name] = value
+        self.registered()[name] = value
 
     def unregister_driver(self, name):
         """Remove runtime registered driver"""
-        self.registered.pop(name)
+        name = _normalize(name)
+        self.registered().pop(name)
 
     def enable(self, name, driver=None):
         """
@@ -141,12 +151,14 @@ class DriverSouces:
             If None, simply remove driver disable flag, if it is found
         """
         config = self.conf
-        if 'drivers' not in config:
-            config['drivers'] = {}
+        if "drivers" not in config:
+            config["drivers"] = {}
         if driver:
-            config['drivers'][name] = driver
-        elif config['drivers'].get(name) is False:
-            del config['drivers'][name]
+            config["drivers"][name] = driver
+        elif config["drivers"].get(name) is False:
+            del config["drivers"][name]
+        if name in self.disabled():
+            self.disabled().remove(name)
         config.save()
 
     def disable(self, name):
@@ -159,11 +171,16 @@ class DriverSouces:
         name : string
             As in ``'zarr'``
         """
+        name = _normalize(name)
         config = self.conf
-        if 'drivers' not in config:
-            config['drivers'] = {}
-        config['drivers'][name] = False
+        if "drivers" not in config:
+            config["drivers"] = {}
+        config["drivers"][name] = False
         config.save()
+        self.disabled().add(name)
+
+
+drivers = DriverSouces()
 
 
 def _load_entrypoint(entrypoint):
@@ -173,17 +190,16 @@ def _load_entrypoint(entrypoint):
     try:
         return entrypoint.load()
     except ImportError as err:
-        raise ConfigurationError(
-            f"Failed to load {entrypoint.name} driver because module "
-            f"{entrypoint.module_name} could not be imported.") from err
+        raise ConfigurationError(f"Failed to load {entrypoint.name} driver because module " f"{entrypoint.module_name} could not be imported.") from err
     except AttributeError as err:
         raise ConfigurationError(
             f"Failed to load {entrypoint.name} driver because no object "
             f"named {entrypoint.object_name} could be found in the module "
-            f"{entrypoint.module_name}.") from err
+            f"{entrypoint.module_name}."
+        ) from err
 
 
-def _package_scan(path=None, plugin_prefix='intake_'):
+def _package_scan(path=None, plugin_prefix="intake_"):
     """Scan for intake drivers and return a dict of plugins.
 
     This searches path (or sys.path) for packages with names that start with
@@ -204,19 +220,27 @@ def _package_scan(path=None, plugin_prefix='intake_'):
                 if plugin_name in plugins:
                     orig_path = inspect.getfile(plugins[plugin_name])
                     new_path = inspect.getfile(plugin)
-                    warnings.warn('Plugin name collision for "%s" from'
-                                  '\n    %s'
-                                  '\nand'
-                                  '\n    %s'
-                                  '\nKeeping plugin from first location.'
-                                  % (plugin_name, orig_path, new_path))
+                    warnings.warn(
+                        'Plugin name collision for "%s" from'
+                        "\n    %s"
+                        "\nand"
+                        "\n    %s"
+                        "\nKeeping plugin from first location." % (plugin_name, orig_path, new_path)
+                    )
                 else:
                     plugins[plugin_name] = plugin
             logger.debug("Import %s took: %7.2f s" % (name, time.time() - t))
     return plugins
 
 
-drivers = DriverSouces()
+def _normalize(name):
+    if not name.isidentifier():
+        # primitive name normalization
+        name = re.sub("[-=~^&|@+]", "_", name)
+    if not name.isidentifier():
+        warnings.warn('Invalid Intake plugin name "%s" found.', name, stacklevel=2)
+
+    return name
 
 
 def load_plugins_from_module(module_name):
@@ -225,15 +249,16 @@ def load_plugins_from_module(module_name):
     Plugin classes are instantiated and added to the dictionary, keyed by the
     name attribute of the plugin object.
     """
-    from intake.source import DataSource
     from intake.catalog import Catalog
+    from intake.source import DataSource
+
     plugins = {}
 
     try:
         try:
             mod = importlib.import_module(module_name)
         except ImportError as error:
-            if module_name.endswith('.py'):
+            if module_name.endswith(".py"):
                 # Provide a specific error regarding the removal of behavior
                 # that intake formerly supported.
                 raise ImportError(
@@ -241,7 +266,8 @@ def load_plugins_from_module(module_name):
                     "files not on the sys.path. This is no longer supported. "
                     "Drivers must be specific with a module path like "
                     "'package_name.module_name, not a Python filename like "
-                    "'module.py'.") from error
+                    "'module.py'."
+                ) from error
             else:
                 raise
     except Exception as e:
@@ -257,5 +283,3 @@ def load_plugins_from_module(module_name):
 
 class ConfigurationError(Exception):
     pass
-
-
