@@ -58,9 +58,7 @@ class JSONFileSource(DataSource):
         self.compression = compression
         if compression is not None:
             if compression not in VALID_COMPRESSIONS:
-                raise ValueError(
-                    f"Compression value {compression} must be one of {VALID_COMPRESSIONS}"
-                )
+                raise ValueError(f"Compression value {compression} must be one of {VALID_COMPRESSIONS}")
         self.mode = "rt" if text_mode else "rb"
         self.encoding = text_encoding
         self._read = read
@@ -138,9 +136,7 @@ class JSONLinesFileSource(DataSource):
         self.compression = compression
         if compression is not None:
             if compression not in VALID_COMPRESSIONS:
-                raise ValueError(
-                    f"Compression value {compression} must be one of {VALID_COMPRESSIONS}"
-                )
+                raise ValueError(f"Compression value {compression} must be one of {VALID_COMPRESSIONS}")
         self.mode = "rt" if text_mode else "rb"
         self.encoding = text_encoding
         self._read = read
